==> qtjambi-xmlpatterns-5.15.10-sources.jar: io/qt/xmlpatterns/QSimpleXmlNodeModel.java <==
package io.qt.xmlpatterns;


/**
 * <p>Implementation of QAbstractXmlNodeModel sufficient for many common cases</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html">QSimpleXmlNodeModel</a></p>
 */
public abstract class QSimpleXmlNodeModel extends io.qt.xmlpatterns.QAbstractXmlNodeModel
    implements java.lang.Cloneable
{
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSimpleXmlNodeModel {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        protected java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> attributes(io.qt.xmlpatterns.QXmlNodeModelIndex element){
            return attributes_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(element));
        }
        @io.qt.QtUninvokable
        private native java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> attributes_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long element);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.xmlpatterns.QXmlNodeModelIndex.DocumentOrder compareOrder(io.qt.xmlpatterns.QXmlNodeModelIndex ni1, io.qt.xmlpatterns.QXmlNodeModelIndex ni2){
            return io.qt.xmlpatterns.QXmlNodeModelIndex.DocumentOrder.resolve(compareOrder_native_cref_QXmlNodeModelIndex_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni1), QtJambi_LibraryUtilities.internal.checkedNativeId(ni2)));
        }
        @io.qt.QtUninvokable
        private native int compareOrder_native_cref_QXmlNodeModelIndex_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni1, long ni2);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QUrl documentUri(io.qt.xmlpatterns.QXmlNodeModelIndex ni){
            return documentUri_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QUrl documentUri_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.xmlpatterns.QXmlNodeModelIndex.NodeKind kind(io.qt.xmlpatterns.QXmlNodeModelIndex ni){
            return io.qt.xmlpatterns.QXmlNodeModelIndex.NodeKind.resolve(kind_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni)));
        }
        @io.qt.QtUninvokable
        private native int kind_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.xmlpatterns.QXmlName name(io.qt.xmlpatterns.QXmlNodeModelIndex ni){
            return name_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni));
        }
        @io.qt.QtUninvokable
        private native io.qt.xmlpatterns.QXmlName name_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @io.qt.QtUninvokable
        protected io.qt.xmlpatterns.QXmlNodeModelIndex nextFromSimpleAxis(io.qt.xmlpatterns.QAbstractXmlNodeModel.SimpleAxis axis, io.qt.xmlpatterns.QXmlNodeModelIndex origin){
            return nextFromSimpleAxis_native_QAbstractXmlNodeModel_SimpleAxis_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), axis.value(), QtJambi_LibraryUtilities.internal.checkedNativeId(origin));
        }
        @io.qt.QtUninvokable
        private native io.qt.xmlpatterns.QXmlNodeModelIndex nextFromSimpleAxis_native_QAbstractXmlNodeModel_SimpleAxis_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, int axis, long origin);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.xmlpatterns.QXmlNodeModelIndex root(io.qt.xmlpatterns.QXmlNodeModelIndex n){
            return root_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(n));
        }
        @io.qt.QtUninvokable
        private native io.qt.xmlpatterns.QXmlNodeModelIndex root_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long n);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.Object typedValue(io.qt.xmlpatterns.QXmlNodeModelIndex n){
            return typedValue_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(n));
        }
        @io.qt.QtUninvokable
        private native java.lang.Object typedValue_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long n);
        
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html#QSimpleXmlNodeModel">QSimpleXmlNodeModel::QSimpleXmlNodeModel(QXmlNamePool)</a></p>
     */
    public QSimpleXmlNodeModel(io.qt.xmlpatterns.QXmlNamePool namePool){
        super((QPrivateConstructor)null);
        initialize_native(this, namePool);
    }
    
    private native static void initialize_native(QSimpleXmlNodeModel instance, io.qt.xmlpatterns.QXmlNamePool namePool);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html#namePool">QSimpleXmlNodeModel::namePool()const</a></p>
     */
    @io.qt.QtUninvokable
    private final io.qt.xmlpatterns.QXmlNamePool namePool_private(){
        return namePool_private_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xmlpatterns.QXmlNamePool namePool_private_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#baseUri">QAbstractXmlNodeModel::baseUri(QXmlNodeModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QUrl baseUri(io.qt.xmlpatterns.QXmlNodeModelIndex node){
        return baseUri_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(node));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl baseUri_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#elementById">QAbstractXmlNodeModel::elementById(QXmlName)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xmlpatterns.QXmlNodeModelIndex elementById(io.qt.xmlpatterns.QXmlName id){
        return elementById_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xmlpatterns.QXmlNodeModelIndex elementById_native_cref_QXmlName_constfct(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#namespaceBindings">QAbstractXmlNodeModel::namespaceBindings(QXmlNodeModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.xmlpatterns.QXmlName> namespaceBindings(io.qt.xmlpatterns.QXmlNodeModelIndex arg__1){
        return namespaceBindings_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native java.util.List<io.qt.xmlpatterns.QXmlName> namespaceBindings_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#nodesByIdref">QAbstractXmlNodeModel::nodesByIdref(QXmlName)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> nodesByIdref(io.qt.xmlpatterns.QXmlName idref){
        return nodesByIdref_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(idref));
    }
    
    @io.qt.QtUninvokable
    private native java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> nodesByIdref_native_cref_QXmlName_constfct(long __this__nativeId, long idref);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#stringValue">QAbstractXmlNodeModel::stringValue(QXmlNodeModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String stringValue(io.qt.xmlpatterns.QXmlNodeModelIndex node){
        return stringValue_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(node));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String stringValue_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long node);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSimpleXmlNodeModel(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-xmlpatterns-5.15.15-sources.jar: io/qt/xmlpatterns/QSimpleXmlNodeModel.java <==
package io.qt.xmlpatterns;

import io.qt.*;


/**
 * <p>Implementation of QAbstractXmlNodeModel sufficient for many common cases</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html">QSimpleXmlNodeModel</a></p>
 */
public abstract class QSimpleXmlNodeModel extends io.qt.xmlpatterns.QAbstractXmlNodeModel
{
    @NativeAccess
    private static final class ConcreteWrapper extends QSimpleXmlNodeModel {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        protected java.util.@NonNull List<io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex> attributes(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex element){
            return attributes_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(element));
        }
        @QtUninvokable
        private native java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> attributes_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long element);
        
        
        @Override
        @QtUninvokable
        public io.qt.xmlpatterns.QXmlNodeModelIndex.@NonNull DocumentOrder compareOrder(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex ni1, io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex ni2){
            return io.qt.xmlpatterns.QXmlNodeModelIndex.DocumentOrder.resolve(compareOrder_native_cref_QXmlNodeModelIndex_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni1), QtJambi_LibraryUtilities.internal.checkedNativeId(ni2)));
        }
        @QtUninvokable
        private native int compareOrder_native_cref_QXmlNodeModelIndex_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni1, long ni2);
        
        
        @Override
        @QtUninvokable
        public io.qt.core.@NonNull QUrl documentUri(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex ni){
            return documentUri_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni));
        }
        @QtUninvokable
        private native io.qt.core.QUrl documentUri_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @QtUninvokable
        public io.qt.xmlpatterns.QXmlNodeModelIndex.@NonNull NodeKind kind(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex ni){
            return io.qt.xmlpatterns.QXmlNodeModelIndex.NodeKind.resolve(kind_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni)));
        }
        @QtUninvokable
        private native int kind_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @QtUninvokable
        public io.qt.xmlpatterns.@NonNull QXmlName name(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex ni){
            return name_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(ni));
        }
        @QtUninvokable
        private native io.qt.xmlpatterns.QXmlName name_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long ni);
        
        
        @Override
        @QtUninvokable
        protected io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex nextFromSimpleAxis(io.qt.xmlpatterns.QAbstractXmlNodeModel.@NonNull SimpleAxis axis, io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex origin){
            return nextFromSimpleAxis_native_QAbstractXmlNodeModel_SimpleAxis_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), axis.value(), QtJambi_LibraryUtilities.internal.checkedNativeId(origin));
        }
        @QtUninvokable
        private native io.qt.xmlpatterns.QXmlNodeModelIndex nextFromSimpleAxis_native_QAbstractXmlNodeModel_SimpleAxis_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, int axis, long origin);
        
        
        @Override
        @QtUninvokable
        public io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex root(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex n){
            return root_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(n));
        }
        @QtUninvokable
        private native io.qt.xmlpatterns.QXmlNodeModelIndex root_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long n);
        
        
        @Override
        @QtUninvokable
        public java.lang.Object typedValue(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex n){
            return typedValue_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(n));
        }
        @QtUninvokable
        private native java.lang.Object typedValue_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long n);
        
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html#QSimpleXmlNodeModel">QSimpleXmlNodeModel::QSimpleXmlNodeModel(QXmlNamePool)</a></p>
     */
    public QSimpleXmlNodeModel(io.qt.xmlpatterns.@NonNull QXmlNamePool namePool){
        super((QPrivateConstructor)null);
        initialize_native(this, namePool);
    }
    
    private native static void initialize_native(QSimpleXmlNodeModel instance, io.qt.xmlpatterns.QXmlNamePool namePool);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsimplexmlnodemodel.html#namePool">QSimpleXmlNodeModel::namePool()const</a></p>
     */
    @QtUninvokable
    public final io.qt.xmlpatterns.@NonNull QXmlNamePool namePool(){
        return namePool_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlNamePool namePool_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#baseUri">QAbstractXmlNodeModel::baseUri(QXmlNodeModelIndex)const</a></p>
     */
    @QtUninvokable
    public io.qt.core.@NonNull QUrl baseUri(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex node){
        return baseUri_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(node));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl baseUri_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#elementById">QAbstractXmlNodeModel::elementById(QXmlName)const</a></p>
     */
    @QtUninvokable
    public io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex elementById(io.qt.xmlpatterns.@NonNull QXmlName id){
        return elementById_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @QtUninvokable
    private native io.qt.xmlpatterns.QXmlNodeModelIndex elementById_native_cref_QXmlName_constfct(long __this__nativeId, long id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#namespaceBindings">QAbstractXmlNodeModel::namespaceBindings(QXmlNodeModelIndex)const</a></p>
     */
    @QtUninvokable
    public java.util.@NonNull List<io.qt.xmlpatterns.@NonNull QXmlName> namespaceBindings(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex arg__1){
        return namespaceBindings_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native java.util.List<io.qt.xmlpatterns.QXmlName> namespaceBindings_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#nodesByIdref">QAbstractXmlNodeModel::nodesByIdref(QXmlName)const</a></p>
     */
    @QtUninvokable
    public java.util.@NonNull List<io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex> nodesByIdref(io.qt.xmlpatterns.@NonNull QXmlName idref){
        return nodesByIdref_native_cref_QXmlName_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(idref));
    }
    
    @QtUninvokable
    private native java.util.List<io.qt.xmlpatterns.QXmlNodeModelIndex> nodesByIdref_native_cref_QXmlName_constfct(long __this__nativeId, long idref);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractxmlnodemodel.html#stringValue">QAbstractXmlNodeModel::stringValue(QXmlNodeModelIndex)const</a></p>
     */
    @QtUninvokable
    public java.lang.@NonNull String stringValue(io.qt.xmlpatterns.@NonNull QXmlNodeModelIndex node){
        return stringValue_native_cref_QXmlNodeModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(node));
    }
    
    @QtUninvokable
    private native java.lang.String stringValue_native_cref_QXmlNodeModelIndex_constfct(long __this__nativeId, long node);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QSimpleXmlNodeModel(QPrivateConstructor p) { super(p); } 
    
}
